==> react-native-credit-card-0.1.0.tgz: package/index.js <==
'use strict';

import React from 'react';
const {
    PropTypes,
    Component
} = React;

import Payment from 'Payment';

import {
    View,
    TouchableOpacity,
    Text,
    StyleSheet,
    Platform,
    Image
} from 'react-native';
const images = require('./card-images');

class CardView extends Component {
    constructor(props) {

    }
    render() {
        const isAmex = this.state.type && this.state.type.name === "amex";
        return (
            <View style={[styles.container, {width: this.props.width, height: this.props.height, backgroundColor: this.props.bgColor}]}>
                <View style={this.props.focused == "cvc" && !isAmex ? styles.flipped : styles.default}>

                    <View style={styles.front}>
                        <View style={styles.lower}>
                            <View style={styles.shiny} />
                            <Image
                                 style={styles.logo}
                                 source={{uri: images[this.props.type ? this.props.type : this.state.type.name]}}
                            />
                            {isAmex ? 
                                <View style={styles.cvc_front}>
                                    {this.getValue("cvc")}
                                </View>
                                : null}
                            <View style={styles.number}>{this.getValue("number")}</View>
                            <View style={styles.name}>{this.getValue("name")}</View>
                            <View
                                style={styles.expiry}
                                data-before={this.props.expiryBefore}
                                data-after={this.props.expiryAfter}>
                                {this.getValue("expiry")}
                            </View>
                        </View>
                    </View>

                    <View style={styles.back}>
                        <View style={styles.bar}/>
                        <View style={styles.cvc}>{this.getValue("cvc")}</View>
                        <View style={styles.shiny} data-after={this.props.shinyAfterBack}/>
                    </View>
                </View>
            </View>
        );
    }
}

const styles = StyleSheet.create({
    container: {

    },
    logo: {
        height: 35,
        width: 57
    }
});

CardView.defaultProps = {
    number: null
    cvc: null
    name: ''
    expiry: ''
    focused: null
    expiryBefore: 'month/year'
    expiryAfter: 'valid thru'
    shinyAfterBack: ''
    type: null,
    width: 350,
    height: 200,
    bgColor: '#191278' 
};

module.exports = CardView;

==> react-native-credit-card-0.1.2.tgz: package/index.js <==
'use strict';

import React from 'react';
const {
    PropTypes,
    Component
} = React;

import Payment from 'Payment';

import {
    View,
    TouchableOpacity,
    Text,
    StyleSheet,
    Platform,
    Image
} from 'react-native';
const images = require('./card-images');

class CardView extends Component {
    constructor(props) {
        super(props);
    }
    render() {
        const isAmex = this.state.type && this.state.type.name === "amex";
        return (
            <View style={[styles.container, {width: this.props.width, height: this.props.height, backgroundColor: this.props.bgColor}]}>
                <View style={this.props.focused == "cvc" && !isAmex ? styles.flipped : styles.default}>

                    <View style={styles.front}>
                        <View style={styles.lower}>
                            <View style={styles.shiny} />
                            <Image
                                 style={styles.logo}
                                 source={{uri: images[this.props.type ? this.props.type : this.state.type.name]}}
                            />
                            {isAmex ? 
                                <View style={styles.cvc_front}>
                                    {this.getValue("cvc")}
                                </View>
                                : null}
                            <View style={styles.number}>{this.getValue("number")}</View>
                            <View style={styles.name}>{this.getValue("name")}</View>
                            <View
                                style={styles.expiry}
                                data-before={this.props.expiryBefore}
                                data-after={this.props.expiryAfter}>
                                {this.getValue("expiry")}
                            </View>
                        </View>
                    </View>

                    <View style={styles.back}>
                        <View style={styles.bar}/>
                        <View style={styles.cvc}>{this.getValue("cvc")}</View>
                        <View style={styles.shiny} data-after={this.props.shinyAfterBack}/>
                    </View>
                </View>
            </View>
        );
    }
}

const styles = StyleSheet.create({
    container: {

    },
    logo: {
        height: 35,
        width: 57
    }
});

CardView.defaultProps = {
    number: null,
    cvc: null,
    name: '',
    expiry: '',
    focused: null,
    expiryBefore: 'month/year',
    expiryAfter: 'valid thru',
    shinyAfterBack: '',
    type: null,
    width: 350,
    height: 200,
    bgColor: '#191278',
};

module.exports = CardView;
